@@ -1,6 +1,6 @@
+from .notification import Notification
 from .notification import notification
 
-
-notification = Notification = notification
+__version__ = '0.0.16'
 
 __all__ = ["Notification", "notification"]
